%define anolis_release 1

Name:           brotli
Version:        1.1.0
Release:        %{anolis_release}%{?dist}
Summary:        Lossless compression algorithm

License:        MIT
URL:            https://github.com/google/brotli
Source0:        %{url}/archive/v%{version}/%{name}-%{version}.tar.gz

BuildRequires:  gcc gcc-c++ cmake
BuildRequires:  python3-devel
BuildRequires:  python%{python3_pkgversion}-setuptools
BuildRequires:  python3-rpm-macros
Requires: lib%{name} = %{version}-%{release}

%description
Brotli is an open-source lossless compression algorithm developed by Google.
It was released in 2015 and is designed to compress data more efficiently than
other popular compression algorithms like Gzip, Zopfli, and Deflate.

Brotli uses a combination of a modern variant of the LZ77 algorithm, Huffman
coding, and a static dictionary to achieve high compression ratios. The
algorithm works by identifying repeated patterns in the data stream and
replacing them with shorter symbols. The dictionary contains frequently used
patterns, which further improves compression efficiency. Brotli also uses
"context modeling," which means that it takes into account the context of the
data being compressed, such as the data type or the position within the file.

One of the key advantages of Brotli is that it achieves higher compression
ratios compared to other algorithms, resulting in smaller file sizes. This
makes it ideal for use in web applications where reducing page load times and
bandwidth usage is critical. Brotli is supported by major web browsers like
Google Chrome, Mozilla Firefox, and Microsoft Edge, as well as many HTTP
servers.

Another advantage of Brotli is its speed. While it is generally slower than
Gzip or Deflate when compressing data, it is faster when decompressing data.
This means that the overall performance of a web page can be improved because
Brotli-compressed files can be served faster, resulting in a better user
experience.

In summary, Brotli is a modern and efficient compression algorithm that offers
higher compression ratios and faster decompression speeds compared to other
compression algorithms. Its adoption by major web browsers and HTTP servers has
made it an important tool for web developers looking to optimize their
website's performance.

#Developers can use these functions to compress data in a variety of formats,
#such as text, images, and video. Libbrotli also provides support for custom
#dictionaries, which can be used to improve compression efficiency for specific
#types of data. Developers can create their own dictionaries or use pre-built
#dictionaries provided by Google.
%package -n libbrotli
Summary:        Library for brotli lossless compression algorithm

%description -n libbrotli
Brotli is a generic-purpose lossless compression algorithm that compresses
data using a combination of a modern variant of the LZ77 algorithm, Huffman
coding and 2nd order context modeling, with a compression ratio comparable
to the best currently available general-purpose compression methods.
It is similar in speed with deflate but offers more dense compression.

%package devel
Summary:        Lossless compression algorithm (development files)
Requires: %{name} = %{version}-%{release}
Requires: lib%{name} = %{version}-%{release}

%description devel
Brotli-devel is a development package that provides the necessary files,
libraries, and headers required for developing applications that use the
Brotli compression algorithm. Brotli is a relatively new compression algorithm
developed by Google, which aims to provide better compression ratio and speed
than existing algorithms like Gzip and Deflate.

The brotli-devel package includes the brotli library, which is a C
implementation of the Brotli compression algorithm. The library provides a
simple and easy-to-use API for compressing and decompressing data in C
applications. It also includes a command-line tool for testing and benchmarking
the algorithm.

Developers can use the brotli-devel package to create software applications
that use the Brotli compression algorithm. The package is available on various
operating systems, such as Linux and macOS, and can be installed using package
managers like YUM and Homebrew.

Overall, brotli-devel is a useful development package for developers who want
to leverage the high compression ratio and speed of Brotli in their
applications. It provides an easy way to integrate the algorithm into C
applications and can help improve the performance and efficiency of data
compression in those applications.

%package -n python%{python3_pkgversion}-%{name}
Summary:        Lossless compression algorithm (python 3)
%{?python_provide:%python_provide python%{python3_pkgversion}-%{name}}

%description -n python%{python3_pkgversion}-%{name}
Python3-brotli is a Python module that provides a Python interface for
the Brotli compression algorithm. Brotli is a relatively new compression
algorithm developed by Google, which aims to provide better compression
ratio and speed than existing algorithms like Gzip and Deflate.

Python3-brotli module allows developers to compress and decompress data
using Brotli algorithm directly from their Python applications. The module
provides a simple and easy-to-use API for compressing and decompressing
data in bytes format. Developers can use it to compress and decompress a
wide range of data types, such as text, images, audio, and video.

Python3-brotli is compatible with both Python 3.x and PyPy 3.x. It is
available as an open-source package and can be installed using Python
package managers like pip. Python3-brotli is licensed under the Apache
License, Version 2.0, which allows developers to use it in both open-source
and proprietary projects.

Overall, Python3-brotli provides a convenient way for Python developers to
leverage the high compression ratio and speed of Brotli in their
applications, making it a useful addition to any Python toolkit.

%package doc
Summary: Documentation files for %{name}
Requires: %{name} = %{version}-%{release}
BuildArch: noarch

%description doc
The %{name}-doc package contains documentation files for %{name}

%prep
%autosetup -p1
# fix permissions for -debuginfo
# rpmlint will complain if I create an extra %%files section for
# -debuginfo for this so we'll put it here instead
chmod 644 c/enc/*.[ch]
chmod 644 c/include/brotli/*.h
chmod 644 c/tools/brotli.c

%build
%cmake \
    -DCMAKE_INSTALL_PREFIX="%{_prefix}" \
    -DCMAKE_INSTALL_LIBDIR="%{_libdir}"
%cmake_build
%py3_build

%install
%cmake_install

%py3_install
install -dm755 "%{buildroot}%{_mandir}/man3"
cd docs
for i in *.3;do
install -m644 "$i" "%{buildroot}%{_mandir}/man3/${i}brotli"
done

%generate_compatibility_deps

%check
%ctest

%files
%{_bindir}/brotli
%{abidir}/brotli-option.list

%files -n libbrotli
%dir %{abidir}
%{_libdir}/libbrotlidec.so.1*
%{_libdir}/libbrotlienc.so.1*
%{_libdir}/libbrotlicommon.so.1*
%{abidir}/libbrotlidec.dump
%{abidir}/libbrotlienc.dump
%{abidir}/libbrotlicommon.dump
%license LICENSE

# Note that there is no %%files section for the unversioned python module
# if we are building for several python runtimes
%files -n python%{python3_pkgversion}-%{name}
%{python3_sitearch}/brotli.py
%{python3_sitearch}/_brotli.cpython-%{python3_version_nodots}*.so
%{python3_sitearch}/Brotli-%{version}-py%{python3_version}.egg-info
%{python3_sitearch}/__pycache__/brotli.cpython-%{python3_version_nodots}*.py*
%{abidir}/_brotli.cpython-%{python3_version_nodots}-%{_arch}-linux-gnu.dump
%license LICENSE

%files devel
%{_includedir}/brotli
%{_libdir}/libbrotlidec.so
%{_libdir}/libbrotlienc.so
%{_libdir}/libbrotlicommon.so
%{_mandir}/man3/types.h.3brotli*
%{_mandir}/man3/encode.h.3brotli*
%{_mandir}/man3/decode.h.3brotli*
%{_mandir}/man3/constants.h.3brotli*
%{_libdir}/pkgconfig/libbrotlidec.pc
%{_libdir}/pkgconfig/libbrotlienc.pc
%{_libdir}/pkgconfig/libbrotlicommon.pc

%files doc
%doc README

%changelog
* Tue Feb 27 2024 mgb01105731 <mgb01105731@alibaba-inc.com> - 1.1.0-1
- update to 1.1.0
- Fix build error

* Wed Apr 12 2023 Xuchun Shang <xuchun.shang@linux.alibaba.com> - 1.0.9-5
- Optimize the spec

* Mon Jan 09 2023 Xuchun Shang <xuchun.shang@linux.alibaba.com> - 1.0.9-4
- Add doc package

* Tue Nov 01 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 1.0.9-3
- optimise spec file

* Wed Oct 12 2022 <fundawang@yeah.net> - 1.0.9-2
- Add upstream patch to Revert "Add runtime linker path to pkg-config files"

* Tue Mar 08 2022 pangqing <pangqing@uniontech.com> - 1.0.9-1
- Init for anolisOS 23

